package design_example_map;

/**
 * Control which interfaces between BlobGui (View) and BlobManager (Model0
 * @author dgibson
 *
 */
public class BlobController {
	private BlobGui gui;
	private BlobManager blobManager;
	
	public BlobController(BlobGui gui) {
		this.gui = gui;  // Link Controller to View
		// Link Controller to Model. Reads data from disc to build Model.
		// Not implemented, returns an empty BlobManager.
		this.blobManager = BlobPersistence.buildBlobManager(gui.inFile);
	}
	
	public void addBlob(String id) {
		// Check to see if id is valid
		BlobIdStatus blobMessage = BlobValidator.isIdValid(id);
		
		if(blobMessage.isValid()) {  // If id is valid
			if(!blobManager.containsBlob(id)) {  // If Blob with id doesn't already exist
				// Update Model - add Blob to BlobManager
				Blob b = new Blob(id);
				blobManager.addBlob(b);
				// Update View - display confirmation of add
				gui.txfId.setText("");
				gui.txfId.requestFocus();
				gui.txaResults.setText(String.format("Blob with id %s added", b.getId()));
			}
			else {  // If Blob with id already exists
				// Update View - display not added message
				gui.txfId.requestFocus();
				gui.txaResults.setText(String.format("Blob with id: %s not added\nBlob with that id already exists", id));
			}
		} 
		else {  // If id is not valid
			// Update View - display message about why id is invalid
			gui.txfId.requestFocus();
			gui.txaResults.setText(String.format("Blob with id: %s not added\nerror message=%s", id, blobMessage.getErrorMessage()));
		}
	}
	
	public void reset() {
		// Update Model - remove all Blobs from BlobManager
		blobManager.clear();
		// Update View - display confirmation
		gui.txfId.setText("");
		gui.txfId.requestFocus();
		gui.txaResults.setText("All Blobs removed");
	}
	
	public void showAll() {
		// Update View - display all Blobs
		gui.txaResults.setText(blobManager.toString());
	}

	public void save() {
		// Save Blobs to disc. Not implemented.
		BlobPersistence.saveBlobs(gui.outFile, blobManager);
		// Update View - display confirmation.
		gui.txaResults.setText("Blobs saved to file");
	}

	public static void main(String[] args) {
	}
}
