package design_example_map;

/**
 * Represents the status of an Blob id before the Blob is created.
 * @author dgibson
 *
 */
public class BlobIdStatus {
	private String id;
	private boolean isValid;
	private String errorMessage;
	/**
	 * Creates a BlobIdStatus for the situation where a proposed Blob id is invalid
	 * @param id The proposed id for a Blob
	 * @param isValid True if the id is valid, false otherwise. The way this constructor
	 * is used in BlobValidator, it is always passed the value False.
	 * @param errorMessage Contains description of why id is invalid 
	 */
	public BlobIdStatus(String id, boolean isValid, String errorMessage) {
		this.id = id;
		this.isValid = isValid;
		this.errorMessage = errorMessage;
	}
	/**
	 * Creates a BlobIdStatus for the situation where a proposed Blob id is valid 
	 * @param id The proposed id for a Blob
	 * @param isValid True if the id is valid, false otherwise. The way this constructor
	 * is used in BlobValidator, it is always passed the value True.
	 */
	public BlobIdStatus(String id, boolean isValid) {
		this(id, isValid, null);
	}

	public String getCode() {
		return id;
	}

	public boolean isValid() {
		return isValid;
	}

	public String getErrorMessage() {
		return errorMessage;
	}
	
	@Override
	public String toString() {
		StringBuilder msg = new StringBuilder("BlobMessage: ");
		String line;
		if(isValid) {
			line = String.format("code=%s, isValid=%b", id, isValid);
		}
		else {
			line = String.format("code=%s, isValid=%b, errorMessage=%s", id, isValid, errorMessage);
		}
		msg.append(line);
		return msg.toString();
	}
	
	public static void main(String[] args) {
		BlobIdStatus blobMsg;
		blobMsg = new BlobIdStatus("1234", true);
		System.out.println(blobMsg);
		blobMsg = new BlobIdStatus("4581", false, "Already in use");
		System.out.println(blobMsg);
	}
}
