package design_example_map;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;


/**
 * Manages a list of Blobs.
 * @author dgibson
 *
 */
public class BlobManager {
	private Map<String, Blob> blobs = new TreeMap<>();
	
	public BlobManager() {}
	
	public void addBlob(Blob b) {
		blobs.put(b.getId(), b);
	}
	
	public int getNumBlobs() {
		return blobs.size();
	}
	
	public Blob getBlob(String id) {
		if(blobs.containsKey(id)) {
			return blobs.get(id);
		}
		return null;
	}
	
	public void clear() {
		blobs.clear();
	}
	
	public boolean containsBlob(String id) {
		return blobs.containsKey(id);
	}
	
	@Override
	public String toString() {
		StringBuilder msg = new StringBuilder();
		msg.append("Blobs:\n");
		int i=1;
		for(Blob b : blobs.values()) {
			String line = String.format("%3d. %s\n", i++, b);
			msg.append(line);
		}
		return msg.toString();
	}
	
	public static void main(String[] args) {
		BlobManager man = new BlobManager();
		Blob b;
		b = new Blob("1234");
		man.addBlob(b);
		b = new Blob("0103");
		man.addBlob(b);
		b = new Blob("9662");
		man.addBlob(b);
		System.out.println(man);
	}
	
}
