package design_example_map;
	
import java.io.File;

import javafx.application.Application;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.SingleSelectionModel;
import javafx.scene.control.Tab;
import javafx.scene.control.TabPane;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.event.EventHandler;
import javafx.event.ActionEvent;

public class BlobGui extends Application {
	// Class variables - File
	static final String path = "src/design_example_map/";
	// Airport file names
	static final String blobsInFileName = path + "inBlobs.txt";
	static final String blobsOutFileName = path + "outBlobs.txt";
	File inFile = new File(blobsInFileName);
	File outFile = new File(blobsInFileName);
	
	// Instance Variables - GUI
	TextField txfId = new TextField();
	Button btnAddBlob = new Button("Add Blob");
	Button btnShowAll = new Button("Show All");
	Button btnSave = new Button("Save");
	
	Button btnReset = new Button("Reset");	
	TextArea txaResults = new TextArea();
	TabPane tabPane = new TabPane();
	SingleSelectionModel<Tab> selectionModel = tabPane.getSelectionModel();
	
	// Instance Variables - State
	BlobController blobController;
	@Override
	public void start(Stage primaryStage) {
		try {
			blobController = new BlobController(this);
			Pane root = buildGui();
			Scene scene = new Scene(root,450,400);
			scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
			primaryStage.setScene(scene);
			primaryStage.setTitle("Blob Manager");
			primaryStage.show();
		} catch(Exception e) {
			e.printStackTrace();
		}
	}

	private Pane buildGui() {
		Pane pan = buildTabPane();
		return pan;
	}
	
	private Pane buildTabPane() {
		BorderPane brdPane = new BorderPane();
		tabPane.setTabClosingPolicy(TabPane.TabClosingPolicy.UNAVAILABLE);
		// Build Tab 1
		Tab tab1 = new Tab();
		tab1.setText("Blobs");
		tab1.setContent(buildTab1Content());

		//-------------not used---------
		// Build Tab 2
//		Tab tab2 = new Tab();
//		tab2.setText("Tab 2");
//		tab2.setContent(buildTab2Content());
		
		// Add tabs to TabPane
		tabPane.getTabs().addAll(tab1);
		// Add TabPane to BorderPane
		brdPane.setCenter(tabPane);
		return brdPane;
	}

	private Pane buildTab1Content() {
		GridPane root = new GridPane();
		root.getStyleClass().add("gridpane");
		// Row 1
		root.add(buildIdEntry(),0,0);
		root.add(buildButtonsPane(),1,0);
		// Row 2, spans both columns
		root.add(txaResults, 0, 1);
		GridPane.setColumnSpan(txaResults, 2);
		return root;
	}
	
	private Pane buildIdEntry() {
		HBox outterBox = new HBox();
		outterBox.getStyleClass().add("hbox");
		
		HBox row = new HBox();
		row.getStyleClass().add("hbox2");
		txfId.requestFocus();
		row.getChildren().addAll(new Label("Id"), txfId);
		
		outterBox.getChildren().addAll(row);
		return outterBox;
	}

	private Pane buildButtonsPane() {
		HBox row = new HBox();
		row.getStyleClass().add("hbox");
		
		// Set event handlers
		// The way we did it in CS 1302
		btnAddBlob.setOnAction(new AddBlobEventHandler() );
		
		// Alternate approach, uses a lambda expression
		btnShowAll.setOnAction(e -> blobController.showAll() );
		btnSave.setOnAction(e -> blobController.save());
		btnReset.setOnAction(e -> blobController.reset() );
		
		// Add buttons to pane
		row.getChildren().addAll(btnAddBlob, btnShowAll, btnSave, btnReset);
		return row;
	}

//	private Pane buildTab2Content() {
//		GridPane root = new GridPane();
//		root.getStyleClass().add("gridpane");
//		Button btnSwitchTab = new Button("Return to Tab 1");
//		btnSwitchTab.setOnAction(new ProcessSwitchTabEventHandler());
//		root.add(btnSwitchTab,0,0);
//		return root;
//	}

	// Event Handlers below
	private class AddBlobEventHandler implements EventHandler<ActionEvent> {
		@Override
		public void handle(ActionEvent event) {
			String id = txfId.getText();
			blobController.addBlob(id);
		}
			
	}

	public static void main(String[] args) {
		launch(args);
	}
}
