package student_data;
	
import javafx.application.Application;
import javafx.beans.value.ChangeListener;
import javafx.beans.value.ObservableValue;
import javafx.stage.Stage;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.ComboBox;
import javafx.scene.control.Label;
import javafx.scene.control.ListView;
import javafx.scene.control.RadioButton;
import javafx.scene.control.SelectionMode;
import javafx.scene.control.SingleSelectionModel;
import javafx.scene.control.Slider;
import javafx.scene.control.Tab;
import javafx.scene.control.TabPane;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.control.ToggleGroup;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;
import javafx.scene.text.Text;
import javafx.event.EventHandler;
import javafx.geometry.Side;
import javafx.event.ActionEvent;

public class Main extends Application {
	TextField txfName = new TextField();
	ComboBox<String> cmbYear = new ComboBox<>();
	RadioButton rbMale = new RadioButton("Male");
	RadioButton rbFemale = new RadioButton("Female");;
	ToggleGroup tGrpSex = new ToggleGroup();
	CheckBox[] chkExtraCurriculars = new CheckBox[3];
	ListView<String> lvwInterests = new ListView<>();
	Button btnProcess = new Button("Process");
	Button btnReset = new Button("Reset");	
	TextArea txaResults = new TextArea();
	Slider sldHappiness = new Slider();
	Label lblHappiness = new Label();
	TabPane tabPane = new TabPane();
	SingleSelectionModel<Tab> selectionModel = tabPane.getSelectionModel();
	@Override
	public void start(Stage primaryStage) {
		try {
			Pane root = buildGui();
			Scene scene = new Scene(root,600,600);
			scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
			primaryStage.setScene(scene);
			primaryStage.setTitle("Example Gui Application");
			primaryStage.show();
		} catch(Exception e) {
			e.printStackTrace();
		}
	}

	private Pane buildGui() {
		Pane pan = buildTabPane();
		return pan;
	}
	
	private Pane buildTabPane() {
		BorderPane brdPane = new BorderPane();
		tabPane.setTabClosingPolicy(TabPane.TabClosingPolicy.UNAVAILABLE);
		// Build Tab 1
		Tab tab1 = new Tab();
		tab1.setText("Student Profile");
		tab1.setContent(buildTab1Content());
		// Build Tab 2
		Tab tab2 = new Tab();
		tab2.setText("Tab 2");
		tab2.setContent(buildTab2Content());
		// Add tabs to TabPane
		tabPane.getTabs().addAll(tab1, tab2);
		// Add TabPane to BorderPane
		brdPane.setCenter(tabPane);
		return brdPane;
	}

	private Pane buildTab1Content() {
		GridPane root = new GridPane();
		root.getStyleClass().add("gridpane");
		// Row 1
		root.add(buildNameAndYearEntry(),0,0);
		root.add(buildSexEntry(),1,0);
		// Row 2
		root.add(buildExtraCurricularEntry(), 0, 1);
		root.add(buildHappinessEntry(), 1, 1);
		// Row 3
		root.add(buildInterestsEntry(), 0, 2);
		root.add(buildButtonsPane(), 1, 2);
		// Row 4, spans both columns
		root.add(txaResults, 0, 3);
		GridPane.setColumnSpan(txaResults, 2);
		return root;
	}
	
	private Pane buildNameAndYearEntry() {
		HBox row = new HBox();
		row.getStyleClass().add("hbox");
		row.getChildren().addAll(buildNameEntry(), buildYearEntry());
		return row;
	}

	private Pane buildNameEntry() {
		HBox row = new HBox();
		row.getStyleClass().add("hbox2");
		txfName.requestFocus();
		row.getChildren().addAll(new Label("Name"), txfName);
		return row;
	}

	private Pane buildYearEntry() {
		HBox hBox = new HBox();
		hBox.getStyleClass().add("hbox2");
		cmbYear.getItems().addAll("Freshman", "Sophomore", "Junior", "Senior");
		cmbYear.setValue("Freshman");
		hBox.getChildren().addAll(new Label("Year"), cmbYear);
		return hBox;
	}
	
	private Pane buildSexEntry() {
		HBox hBox = new HBox();
		hBox.getStyleClass().add("hbox");
	    rbMale.setToggleGroup(tGrpSex);
	    rbMale.setSelected(true);
	    rbFemale.setToggleGroup(tGrpSex);
	    hBox.getChildren().addAll(new Label("Sex: "), rbMale, rbFemale);
		
		return hBox;
	}

	private Pane buildExtraCurricularEntry() {
		HBox hBox = new HBox();
		hBox.getStyleClass().add("hbox");
		chkExtraCurriculars[0] = new CheckBox("Sports");
		chkExtraCurriculars[1] = new CheckBox("Band");
		chkExtraCurriculars[2] = new CheckBox("Clubs");

		hBox.getChildren().add(new Label("Extra Curricular: "));

		for(CheckBox chk : chkExtraCurriculars) {
			hBox.getChildren().add(chk);
		}
		return hBox;
	}

	private Pane buildInterestsEntry() {
		HBox hBox = new HBox();
		hBox.getStyleClass().add("hbox");
		lvwInterests.getSelectionModel().setSelectionMode(SelectionMode.MULTIPLE);
		lvwInterests.getItems().addAll("Music", "Dance", "Disc Golf", "Theater", "Reading");
		hBox.getChildren().addAll(new Text("Interests\nSelect all that apply"), lvwInterests);
		return hBox;
	}

	private Pane buildHappinessEntry() {
		VBox vBox = new VBox();
		vBox.getStyleClass().add("hbox");
		HBox hBox = new HBox();
		hBox.getStyleClass().add("hbox2");
		hBox.getChildren().addAll(new Label("Happiness Index: "), lblHappiness );
		sldHappiness.setMin(0);
		sldHappiness.setMax(10);
		sldHappiness.setValue(5);
		Double happiness = sldHappiness.getValue();
		String strHappiness = String.format("%.1f", happiness);
		lblHappiness.setText(strHappiness);
		sldHappiness.setShowTickLabels(true);
		sldHappiness.setShowTickMarks(true);
		sldHappiness.setMajorTickUnit(2);
		sldHappiness.setMinorTickCount(1);
		sldHappiness.setBlockIncrement(2);
		sldHappiness.valueProperty().addListener(new SliderEventHandler());
		vBox.getChildren().addAll(hBox, sldHappiness);
		return vBox;
	}

	private Pane buildButtonsPane() {
		VBox row = new VBox();
		row.getStyleClass().add("hbox");
		btnProcess.setOnAction(new ProcessButtonEventHandler() );
		btnReset.setOnAction(new ResetButtonEventHandler() );
		row.getChildren().addAll(btnProcess, btnReset);
		return row;
	}

	private Pane buildTab2Content() {
		GridPane root = new GridPane();
		root.getStyleClass().add("gridpane");
		Button btnSwitchTab = new Button("Return to Tab 1");
		btnSwitchTab.setOnAction(new ProcessSwitchTabEventHandler());
		root.add(btnSwitchTab,0,0);
		return root;
	}

	// Event Handlers below
	private class ProcessButtonEventHandler implements EventHandler<ActionEvent> {

		@Override
		public void handle(ActionEvent event) {
			String name = txfName.getText();
			String year = cmbYear.getValue();
			String sex = ((RadioButton)tGrpSex.getSelectedToggle()).getText();
			String extraCurriculars = "";
			for(CheckBox chk : chkExtraCurriculars) {
				if(chk.isSelected()) {
					extraCurriculars += chk.getText() + ", ";
				}
			}
			String interests = "";
			for(String interest : lvwInterests.getSelectionModel().getSelectedItems()) {
				interests += interest + ", ";
			}
			double happiness = sldHappiness.getValue();
			String strHappiness = String.format("%.1f", happiness);

			txaResults.setText(
					"Name             : " + name + "\n" + 
					"Interests        : " + year + "\n" + 
					"Sex              : " + sex + "\n" + 
					"Extra Curriculars: " + extraCurriculars + "\n" + 
					"Interests        : " + interests + "\n" +
					"Happiness:       : " + strHappiness);
		}
			
	}

	private class ResetButtonEventHandler implements EventHandler<ActionEvent> {

		@Override
		public void handle(ActionEvent event) {
			txfName.setText("");
			txfName.requestFocus();
			cmbYear.setValue("Freshman");
			rbMale.setSelected(true);
			for(CheckBox chk : chkExtraCurriculars) {
				chk.setSelected(false);
			}
			lvwInterests.getSelectionModel().clearSelection();
			sldHappiness.setValue(5.0);
			txaResults.clear();
		}
			
	}

	private class SliderEventHandler implements ChangeListener<Number> {

		@Override
		public void changed(ObservableValue<? extends Number> arg0, Number oldVal, Number newVal) {
			Double happiness = (Double) newVal;
			String strHappiness = String.format("%.1f", happiness);
			
			lblHappiness.setText(strHappiness);
			System.out.println(newVal);
		}
			
	}

	private class ProcessSwitchTabEventHandler implements EventHandler<ActionEvent> {

		@Override
		public void handle(ActionEvent event) {
			selectionModel.select(0);
		}
		}

	public static void main(String[] args) {
		launch(args);
	}
	
	
}
